%define anolis_release 1
Name: debugedit
Version: 5.1
Release: %{anolis_release}%{?dist}
Summary: Tools and scripts for creating debuginfo and source file distributions, collect build-ids and rewrite source paths in DWARF data for debugging, tracing and profiling.
License: GPL-3.0-or-later AND GPL-2.0-or-later AND LGPL-2.0-or-later
URL: https://sourceware.org/debugedit/
Source0: https://sourceware.org/pub/debugedit/%{version}/%{name}-%{version}.tar.xz
Source1: https://sourceware.org/pub/debugedit/%{version}/%{name}-%{version}.tar.xz.sig
Source2: gpgkey-5C1D1AA44BE649DE760A.gpg

BuildRequires: make gcc
BuildRequires: pkgconfig(libelf)
BuildRequires: pkgconfig(libdw)
BuildRequires: help2man
BuildRequires: gnupg2

# For configure checking -j support
BuildRequires: dwz

# For debugedit build-id recomputation
BuildRequires: xxhash-devel
# debugedit builds with XXH_INLINE_ALL, so depend on (virtual) xxhash-static
BuildRequires: xxhash-static

# For the testsuite.
BuildRequires: autoconf
BuildRequires: automake

# The find-debuginfo.sh script has a couple of tools it needs at runtime.
# For strip_to_debug, eu-strip
Requires: elfutils
# For add_minidebug, readelf, awk, nm, sort, comm, objcopy, xz
Requires: binutils, gawk, coreutils, xz
# For find and xargs
Requires: findutils
# For do_file, gdb_add_index
# We only need gdb-add-index, so suggest gdb-minimal (full gdb is also ok)
Requires: /usr/bin/gdb-add-index
Suggests: gdb-minimal
# For run_job, sed
Requires: sed
# For dwz
Requires: dwz
# For append_uniq, grep
Requires: grep

%global _hardened_build 1

Patch1: 0001-find-debuginfo-Check-files-are-writable-before-modif.patch
Patch2: 0001-find-debuginfo-Fix-skip_mini-.gnu_debugdata-handling.patch
patch3: 0001-find-debuginfo-Make-return-from-do_file-explicit.patch

%description
The debugedit project provides programs and scripts for creating
debuginfo and source file distributions, collect build-ids and rewrite
source paths in DWARF data for debugging, tracing and profiling.

It is based on code originally from the rpm project plus libiberty and
binutils.  It depends on the elfutils libelf and libdw libraries to
read and write ELF files, DWARF data and build-ids.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -p1

%build
autoreconf -f -v -i
%configure
%make_build

%install
%make_install
# Temp symlink to make sure things don't break.
cd %{buildroot}%{_bindir}
ln -s find-debuginfo find-debuginfo.sh

%generate_compatibility_deps

%check
# The testsuite should be zero fail.
%ifnarch loongarch64
make check %{?_smp_mflags}
%endif

%files
%dir %{abidir}
%license COPYING COPYING3 COPYING.LIB
%{_bindir}/debugedit
%{abidir}/debugedit-option.list
%{_bindir}/sepdebugcrcfix
%{abidir}/sepdebugcrcfix-option.list
%{_bindir}/find-debuginfo
%{abidir}/find-debuginfo-option.list
%{_bindir}/find-debuginfo.sh
%{_mandir}/man1/debugedit.1*
%{_mandir}/man1/sepdebugcrcfix.1*
%{_mandir}/man1/find-debuginfo.1*

%files doc 
%doc README

%changelog
* Fri Feb 28 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 5.1-1
- Refer to CentOS Stream debugedit-5.1-4 (mjw@redhat.com)
- disable check for loongarch64 (zhangwenlong@loongson.cn)
- Add doc sub package

* Fri Nov 10 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 5.0-7
- disable check for loongarch64

* Tue Nov  7 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 5.0-6
- add loongarch64 support for debugedit

* Tue Apr 11 2023 Ziyang Zhang <ZiyangZhang@linux.alibaba.com> -5.0-5
- Optimize spec file

* Sun Feb 26 2023 Funda Wang <fundawang@yeah.net> - 5.0-4
- Sync with upstream patches

* Wed Feb 08 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 5.0-3
- Add abi file

* Sat Oct 08 2022 mgb01105731 <mgb01105731@alibaba0inc.com> - 5.0-2
- add doc package

* Fri May 20 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 5.0-1
- init from upstream
